package com.example.osnov_android.views

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.Card
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import coil.compose.AsyncImagePainter
import coil.compose.rememberAsyncImagePainter
import coil.request.ImageRequest
import com.example.osnov_android.MainActivityViewModel
import com.example.osnov_android.navigation.Screen

@Composable
fun CookingAdmin(viewModel: MainActivityViewModel, navController: NavController) {
    val background = Color(0xFF1B1A20)
    Column(Modifier.fillMaxSize().background(background)) {
        val flag = remember { mutableStateOf(true) }
        val cookings by viewModel.cookings

        if (flag.value) {
            viewModel.allDishes()
            flag.value = false
        }

        Column(
            modifier = Modifier
                .fillMaxSize()
                .background(background)
                .padding(top = 50.dp),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(
                text = "ПРОФИЛЬ",
                fontWeight = FontWeight.Light,
                fontSize = 24.sp,
                color = Color(0xFFFFFFFF),
                letterSpacing = 10.sp
            )

            if (cookings.isNotEmpty()) {
                LazyColumn {
                    items(cookings) { cooking ->
                        val image = rememberAsyncImagePainter(
                            model = ImageRequest.Builder(LocalContext.current).data(cooking.Image)
                                .size(200, 200).build()
                        ).state
                        Card(
                            modifier = Modifier
                                .fillMaxWidth()
                                .padding(20.dp)


                        ) {
                            Column(
                                Modifier.fillMaxSize(),
                                verticalArrangement = Arrangement.Center,
                                horizontalAlignment = Alignment.CenterHorizontally
                            ) {
                                if (image is AsyncImagePainter.State.Success) {
                                    Box(
                                        modifier = Modifier
                                            .height(200.dp)
                                            .padding(10.dp),
                                        contentAlignment = Alignment.Center
                                    ) {
                                        Image(
                                            modifier = Modifier
                                                .fillMaxWidth()
                                                .height(200.dp),
                                            painter = image.painter,
                                            contentDescription = "",
                                            contentScale = ContentScale.Crop,
                                            alignment = Alignment.Center
                                        )
                                    }
                                }
                                if (image is AsyncImagePainter.State.Loading) {
                                    Box(
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .height(250.dp),
                                        contentAlignment = Alignment.Center
                                    ) {
                                        CircularProgressIndicator()
                                    }
                                }
                            }
                            Column(
                                Modifier.fillMaxSize().padding(12.dp),
                                horizontalAlignment = Alignment.Start
                            ) {

                                Text(
                                    text = cooking.Name,
                                    fontWeight = FontWeight.Medium,
                                    fontSize = 20.sp,
                                    color = Color.Black,
                                    modifier = Modifier.padding(5.dp)
                                )
                                Text(
                                    text = cooking.Descriptions,
                                    fontWeight = FontWeight.Light,
                                    fontSize = 14.sp,
                                    color = Color.Black,
                                    modifier = Modifier.padding(5.dp)
                                )

                                Column(
                                    Modifier,
                                    horizontalAlignment = Alignment.CenterHorizontally
                                ) {
                                    Button(
                                        onClick = { viewModel.deleteCooking(cooking.id!!) },
                                        modifier = Modifier
                                            .fillMaxWidth(0.5f)
                                            .padding(5.dp),
                                        shape = RoundedCornerShape(20),
                                        colors = ButtonColors(
                                            contentColor = Color.White,
                                            containerColor = Color(0xFF7DAD01),
                                            disabledContentColor = Color.White,
                                            disabledContainerColor = Color(0xFF7DAD01)
                                        )
                                    ) {
                                        Text("Удалить")
                                    }
                                    Button(
                                        onClick = {
                                            viewModel.giveCooking(cooking)
                                            navController.navigate(Screen.CookingUpdate.route)
                                        }, modifier = Modifier
                                            .fillMaxWidth(0.5f)
                                            .padding(5.dp),
                                        shape = RoundedCornerShape(20),
                                        colors = ButtonColors(
                                            contentColor = Color.White,
                                            containerColor = Color(0xFF7DAD01),
                                            disabledContentColor = Color.White,
                                            disabledContainerColor = Color(0xFF7DAD01)
                                        )
                                    ) {
                                        Text("Изменить")
                                    }
                                }
                            }
                        }
                    }
                }
            } else {
                Box(Modifier.fillMaxSize(), contentAlignment = Alignment.Center) {
                    CircularProgressIndicator()
                }
            }
        }
    }
}
