package com.example.osnov_android.views

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.KeyboardArrowDown
import androidx.compose.material.icons.filled.KeyboardArrowUp
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.geometry.Size
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import coil.compose.rememberAsyncImagePainter
import com.example.osnov_android.MainActivityViewModel
import com.example.osnov_android.navigation.Screen

@Composable
fun Profile(viewModel: MainActivityViewModel, navController: NavController) {
    val background = Color(0xFF1B1A20)
    val user by viewModel.user
    val context = LocalContext.current
    val flag1 = remember { mutableStateOf(false) }
    val userState by viewModel.userState
    val flag = remember { mutableStateOf(true) }
    if (flag.value) {
        viewModel.profileData()
        flag.value = false
    }


    if (user.isNotEmpty()) {
        val name = remember { mutableStateOf(user.last().name) }
        var expanded by remember {
            mutableStateOf(false)
        }
        val list = listOf("Мужской", "Женский")

        var selectedItem by remember {
            mutableStateOf(
                if (user.last().id_gender == 1) {
                    "Мужской"
                } else {
                    "Женский"
                }
            )
        }
        var textFiledSize by remember {
            mutableStateOf(Size.Zero)
        }
        val icon = if (expanded) {
            Icons.Filled.KeyboardArrowUp
        } else {
            Icons.Filled.KeyboardArrowDown
        }
        Column(
            modifier = Modifier
                .fillMaxSize()
                .background(background)
                .padding(top = 50.dp),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text(
                text = "ПРОФИЛЬ",
                fontWeight = FontWeight.Light,
                fontSize = 24.sp,
                color = Color(0xFFFFFFFF),
                letterSpacing = 10.sp
            )
            Spacer(Modifier.height(30.dp))
            Row {
                Box(modifier = Modifier.height(200.dp).width(200.dp),)
                {
                    Column(
                        Modifier.fillMaxSize(),
                        verticalArrangement = Arrangement.Center,
                    ) {
                        Image(
                            modifier = Modifier
                                .fillMaxWidth()
                                .size(200.dp)
                                .clip(CircleShape),
                            painter = rememberAsyncImagePainter(viewModel.users.value.last().image),
                            contentDescription = "",
                            contentScale = ContentScale.Crop,
                            alignment = Alignment.Center
                        )
                    }
                }
                Spacer(Modifier.width(30.dp))
                Box(modifier = Modifier.height(150.dp).width(105.dp))
                {
                    Text(text = viewModel.users.value.last().name,
                        fontWeight = FontWeight.Medium,
                        fontSize = 30.sp,
                        color = Color.White,
                        modifier = Modifier.padding(5.dp))
                }
                }
            Spacer(Modifier.width(60.dp))
            Button(onClick = {
                navController.navigate(Screen.UpdatedataUser.route)
            }, modifier = Modifier
                .fillMaxWidth(0.5f)
                .padding(top = 20.dp),
                shape = RoundedCornerShape(20),
                colors = ButtonColors(
                    contentColor = Color.White,
                    containerColor = Color(0xFF7DAD01),
                    disabledContentColor = Color.White,
                    disabledContainerColor = Color(0xFF7DAD01)
                )
            ) {
                Text(text = "Изменить", fontSize = 24.sp, fontWeight = FontWeight.Light )
            }
        }
    }
    else {
        Box(Modifier.fillMaxSize(), contentAlignment = Alignment.Center) {
            CircularProgressIndicator()
        }
    }
}