package com.example.osnov_android.views

import android.os.Build
import android.util.Log
import android.util.Patterns
import android.widget.Space
import android.widget.Toast
import androidx.annotation.RequiresApi
import androidx.compose.foundation.background
import androidx.compose.foundation.horizontalScroll
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.focus.focusModifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.osnov_android.MainActivityViewModel
import com.example.osnov_android.R
import com.example.osnov_android.components.TextBlockEmail
import com.example.osnov_android.components.TextBlockPassword
import com.example.osnov_android.models.UserState
import com.example.osnov_android.navigation.Screen


@Composable
fun SignIn(navController: NavController, viewModel: MainActivityViewModel) {
    val background = Color(0xFF1B1A20)
    val email = remember { mutableStateOf("") }
    val enable = remember { mutableStateOf(false) }
    val password = remember { mutableStateOf("") }
    val flag = remember { mutableStateOf(false) }
    val userState by viewModel.userState
    var currentUserState by remember { mutableStateOf("") }
    val context = LocalContext.current
    Column(
        modifier = Modifier
            .fillMaxSize()
            .fillMaxHeight()
            .background(background)
    ) {

        Column(
            modifier = Modifier
                .fillMaxWidth(1f)
                .fillMaxHeight(0.4f)
                .background(background),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Icon(
                painterResource(id = R.drawable.icon_pril),
                contentDescription = "Иконка приложения",
                Modifier.height(100.dp),
                tint = Color.White
            )
            Text(
                text = "FOOD EXPERT",
                fontWeight = FontWeight.Light,
                fontSize = 30.sp,
                color = Color(0xFFFFFFFF),
                letterSpacing = 15.sp
            )
            Spacer(modifier = Modifier.height(10.dp))
            Text(
                text = "С возвращением!",
                fontWeight = FontWeight.Light,
                fontSize = 30.sp,
                color = Color(0xFFFFFFFF)
            )
        }
        Column(
            modifier = Modifier
                .fillMaxWidth(1f)
                .background(background),
            horizontalAlignment = Alignment.CenterHorizontally
        )
        {
            TextBlockEmail(
                search = email.value,
                onValueChange = { email.value = it }
            )
            if (Patterns.EMAIL_ADDRESS.matcher(email.value).matches()) {
                enable.value = true
            } else {
                Text(
                    "Некорректная почта",
                    color = Color.Red,
                    textAlign = TextAlign.Center
                )
            }

        }
        Column(
            modifier = Modifier
                .fillMaxWidth(1f), horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Spacer(Modifier.height(20.dp))
            TextBlockPassword(
                text = "Введите пароль",
                search = password.value,
                onValueChange = { password.value = it })
            Spacer(Modifier.height(50.dp))
            Button(
                onClick = {
                    viewModel.SignIn(email.value, password.value)
                    flag.value = true
                },
                Modifier
                    .height(50.dp)
                    .width(200.dp),
                shape = RoundedCornerShape(20),
                enabled = enable.value,
                colors = ButtonColors(
                    contentColor = Color.White,
                    containerColor = Color(0xFF7DAD01),
                    disabledContentColor = Color.White,
                    disabledContainerColor = Color.LightGray
                )
            ) {
                Text(text = "Вход", fontSize = 24.sp, fontWeight = FontWeight.Light)
            }
            Spacer(modifier = Modifier.height(20.dp))
            Button(
                onClick = {
                    navController.navigate(Screen.Start.route)
                },
                Modifier
                    .height(50.dp)
                    .width(200.dp),
                shape = RoundedCornerShape(20),
                enabled = true,
                colors = ButtonColors(
                    contentColor = Color.White,
                    containerColor = Color(0xFF7DAD01),
                    disabledContentColor = Color.White,
                    disabledContainerColor = Color.LightGray
                )
            ) {
                Text(text = "Назад", fontSize = 24.sp, fontWeight = FontWeight.Light)
            }
        }
    }

    if (flag.value) {
        when (userState) {
            is UserState.Loading -> {
                Box(Modifier.fillMaxSize(), contentAlignment = Alignment.Center) {
                    CircularProgressIndicator()
                }
            }

            is UserState.Success -> {

                if (viewModel.users.value.last().id_role == 1) {
                    navController.navigate(Screen.NavigationsAdmin.route)
                } else {
                    navController.navigate(Screen.Navigations.route)
                }

                flag.value = false
            }
                    is UserState.Error -> {
                val message = (userState as UserState.Error).message
                currentUserState = message
                Toast.makeText(context, message, Toast.LENGTH_SHORT).show()
                flag.value = false
            }
        }
        if (currentUserState.isNotEmpty()) {
            println(currentUserState)
        }
    }
}
