package com.example.osnov_android.views.bottom_menu

import android.os.Build
import androidx.annotation.RequiresApi
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.gestures.snapping.SnapPosition
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.NavigationBarItemDefaults
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.NavDestination
import androidx.navigation.NavDestination.Companion.hierarchy
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.NavHostController
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.example.osnov_android.MainActivityViewModel

@RequiresApi(Build.VERSION_CODES.O)
@Composable
fun AppNavigation(viewModel: MainActivityViewModel, mainNavController: NavController)
{
    val navController = rememberNavController()
    val background = Color(0xFF1B1A20)
    Scaffold(modifier = Modifier.fillMaxSize().background(background),
        bottomBar = {BottomMenu(navController = navController)}){
        Column(modifier = Modifier
            .fillMaxSize()
            .padding(it)){
            BottomGraph(viewModel,navController, mainNavController)
        }
    }
}

@Composable
fun AddItem(
    screen: BottomMenuItem,
    currentDestination: NavDestination?,
    navController: NavHostController
) {
    val selected = currentDestination?.hierarchy?.any { it.route == screen.rote } == true

    val background = Color(0xFF1B1A20)

    val contentColor =
        if (selected) Color.White else Color(0xFF35343A)

    Box(
        modifier = Modifier
            .width(95.dp)
            .clip(RoundedCornerShape(10.dp))
            .background(background)
            .clickable(onClick = {
                navController.navigate(screen.rote) {
                    popUpTo(navController.graph.findStartDestination().id)
                    launchSingleTop = true
                }
            }),
    ) {
        Column(
            modifier = Modifier
                .height(60.dp)
                .align(Alignment.Center),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.SpaceEvenly,
        ) {
            Icon(
                painter = painterResource(id = if (selected) screen.iconId else screen.iconId),
                contentDescription = "icon",
                tint = contentColor
            )
            Text(
                text = screen.title,
                color = contentColor,
                fontSize = 12.sp,
                fontWeight = FontWeight.Normal

            )
        }
    }
}

@Composable
fun BottomMenu(navController: NavHostController) {
    val items = listOf(
        BottomMenuItem.Blog,
        BottomMenuItem.Cooking,
        BottomMenuItem.Faq,
        BottomMenuItem.Profile
    )
    val background = Color(0xFF1B1A20)
    val navStackBackEntry by navController.currentBackStackEntryAsState()
    val currentDestination = navStackBackEntry?.destination

    NavigationBar(
        contentColor = background,
        containerColor = background,
    ) {
        items.forEach { item ->
            AddItem(
                screen = item,
                currentDestination = currentDestination,
                navController = navController
                )

        }
    }
}