package com.example.osnov_android.views

import android.os.Build
import androidx.annotation.Dimension
import androidx.annotation.RequiresApi
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.Navigation
import com.example.osnov_android.MainActivityViewModel
import com.example.osnov_android.R
import com.example.osnov_android.navigation.Screen
import com.google.android.gms.auth.api.Auth

@RequiresApi(Build.VERSION_CODES.O)
@Composable
fun Start(navController: NavController) {
    val background = Color(0xFF1B1A20)
    Column(
        modifier = Modifier
            .fillMaxSize()
            .fillMaxHeight()
            .background(background)
    ) {

        Column(
            modifier = Modifier
                .fillMaxWidth(1f)
                .fillMaxHeight(0.5f)
                .background(background),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Icon(painterResource(id = R.drawable.icon_pril), contentDescription = "Иконка приложения", Modifier.height(100.dp), tint = Color.White)
            Text(
                text = "FOOD EXPERT",
                fontWeight = FontWeight.Light,
                fontSize = 30.sp,
                color = Color(0xFFFFFFFF),
                letterSpacing = 15.sp
            )
            Spacer(modifier = Modifier.height(10.dp))
            Text(
                text = "Добро пожаловать!",
                fontWeight = FontWeight.Light,
                fontSize = 30.sp,
                color = Color(0xFFFFFFFF)
            )
            Spacer(modifier = Modifier.height(10.dp))
            Text(
                text = "Мы рады что вы с нами!",
                fontWeight = FontWeight.Light,
                fontSize = 16.sp,
                color = Color(0xFFFFFFFF)
            )
        }
        Column(
            modifier = Modifier
                .fillMaxWidth(1f)
                .fillMaxHeight(0.5f)
                .background(background),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Top
        ) {

            Button(
                onClick = { navController.navigate(Screen.SignIn.route)},
                modifier = Modifier
                    .fillMaxWidth(0.5f)
                    .height(50.dp),
                shape = RoundedCornerShape(20),
                colors = ButtonColors(
                    contentColor = Color.White,
                    containerColor = Color(0xFF7DAD01),
                    disabledContentColor = Color.White,
                    disabledContainerColor = Color(0xFF7DAD01)
                )
            ) {
                Text(text = "Вход", fontSize = 24.sp, fontWeight = FontWeight.Light)
            }
            Spacer(modifier = Modifier.height(20.dp))
            Button(
                onClick = { navController.navigate(Screen.SignUp.route)},
                modifier = Modifier
                    .fillMaxWidth(0.5f)
                    .height(50.dp),
                shape = RoundedCornerShape(20),
                colors = ButtonColors(
                    contentColor = Color.White,
                    containerColor = Color(0xFF7DAD01),
                    disabledContentColor = Color.White,
                    disabledContainerColor = Color(0xFF7DAD01)
                )
            ) {
                Text(text = "Регистрация", fontSize = 24.sp, fontWeight = FontWeight.Light)
            }
        }
    }
}